@@ -1,4 +1,5 @@
-package Data::Validate::WithYAML::Plugin::TestPlugin;
+package
+    Data::Validate::WithYAML::Plugin::TestPlugin;
 
 use strict;
 use warnings;
@@ -13,4 +14,4 @@ sub check {
     return;
 }
 
-1;
\ No newline at end of file
+1;
